@@ -9,33 +9,33 @@
 
 // Qt
 #include <QFileInfo>
-#include <QStandardPaths>
-#include <QStandardItem>
 #include <QKeyEvent>
+#include <QStandardItem>
+#include <QStandardPaths>
 
 // Konsole
+#include "delegates/ProfileShortcutDelegate.h"
 #include "profile/ProfileManager.h"
 #include "profile/ProfileModel.h"
 #include "session/Session.h"
-#include "widgets/EditProfileDialog.h"
-#include "terminalDisplay/TerminalDisplay.h"
-#include "session/SessionManager.h"
 #include "session/SessionController.h"
-#include "delegates/ProfileShortcutDelegate.h"
+#include "session/SessionManager.h"
+#include "terminalDisplay/TerminalDisplay.h"
+#include "widgets/EditProfileDialog.h"
 
 using namespace Konsole;
 
-ProfileSettings::ProfileSettings(QWidget* parent)
+ProfileSettings::ProfileSettings(QWidget *parent)
     : QWidget(parent)
 {
     setupUi(this);
 
-    profilesList->setModel(ProfileModel::instance());
-    profilesList->setItemDelegateForColumn(ProfileModel::SHORTCUT, new ShortcutItemDelegate(this));
-    profilesList->setSelectionMode(QAbstractItemView::SingleSelection);
+    profileListView->setModel(ProfileModel::instance());
+    profileListView->setItemDelegateForColumn(ProfileModel::SHORTCUT, new ShortcutItemDelegate(this));
+    profileListView->setSelectionMode(QAbstractItemView::SingleSelection);
 
     // double clicking the profile name opens the profile edit dialog
-    connect(profilesList, &QAbstractItemView::doubleClicked, this, &Konsole::ProfileSettings::doubleClicked);
+    connect(profileListView, &QAbstractItemView::doubleClicked, this, &Konsole::ProfileSettings::doubleClicked);
 
     // populate the table with profiles
     populateTable();
@@ -57,7 +57,6 @@ ProfileSettings::~ProfileSettings() = default;
 void ProfileSettings::slotAccepted()
 {
     ProfileManager::instance()->saveSettings();
-    deleteLater();
 }
 
 void ProfileSettings::doubleClicked(const QModelIndex &idx)
@@ -71,23 +70,23 @@ void ProfileSettings::populateTable()
 {
     QStyleOptionViewItem opt;
     opt.features = QStyleOptionViewItem::HasCheckIndicator | QStyleOptionViewItem::HasDecoration;
-    auto *listHeader = profilesList->header();
+    auto *listHeader = profileListView->header();
 
-    profilesList->resizeColumnToContents(ProfileModel::NAME);
+    profileListView->resizeColumnToContents(ProfileModel::NAME);
 
     listHeader->setSectionResizeMode(ProfileModel::NAME, QHeaderView::ResizeMode::Stretch);
     listHeader->setSectionResizeMode(ProfileModel::SHORTCUT, QHeaderView::ResizeMode::ResizeToContents);
     listHeader->setStretchLastSection(false);
     listHeader->setSectionsMovable(false);
 
-    profilesList->hideColumn(ProfileModel::PROFILE);
+    profileListView->hideColumn(ProfileModel::PROFILE);
 
     // listen for changes in the table selection and update the state of the form's buttons
     // accordingly.
     //
     // it appears that the selection model is changed when the model itself is replaced,
     // so the signals need to be reconnected each time the model is updated.
-    connect(profilesList->selectionModel(), &QItemSelectionModel::selectionChanged, this, &Konsole::ProfileSettings::tableSelectionChanged);
+    connect(profileListView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &Konsole::ProfileSettings::tableSelectionChanged);
 }
 
 void ProfileSettings::tableSelectionChanged(const QItemSelection &selected)
@@ -151,11 +150,6 @@ void ProfileSettings::createProfile()
     dialog->setProfile(newProfile, EditProfileDialog::NewProfile);
     dialog->selectProfileName();
 
-    connect(dialog, &QDialog::accepted, this, [newProfile]() {
-        ProfileManager::instance()->addProfile(newProfile);
-        ProfileManager::instance()->changeProfile(newProfile, newProfile->setProperties());
-    });
-
     dialog->show();
 }
 void ProfileSettings::editSelected()
@@ -178,17 +172,13 @@ void ProfileSettings::editSelected()
 
 Profile::Ptr ProfileSettings::currentProfile() const
 {
-    QItemSelectionModel* selection = profilesList->selectionModel();
+    QItemSelectionModel *selection = profileListView->selectionModel();
 
     if ((selection == nullptr) || !selection->hasSelection()) {
         return Profile::Ptr();
     }
 
-    return selection
-        ->selectedIndexes()
-        .at(ProfileModel::PROFILE)
-        .data(ProfileModel::ProfilePtrRole)
-        .value<Profile::Ptr>();
+    return selection->selectedIndexes().at(ProfileModel::PROFILE).data(ProfileModel::ProfilePtrRole).value<Profile::Ptr>();
 }
 
 bool ProfileSettings::isProfileDeletable(Profile::Ptr profile) const
@@ -198,18 +188,16 @@ bool ProfileSettings::isProfileDeletable(Profile::Ptr profile) const
     }
 
     const QFileInfo fileInfo(profile->path());
-    return fileInfo.exists()
-        && QFileInfo(fileInfo.path()).isWritable(); // To delete a file, parent dir must be writable
+    return fileInfo.exists() && QFileInfo(fileInfo.path()).isWritable(); // To delete a file, parent dir must be writable
 }
 
 bool ProfileSettings::isProfileWritable(Profile::Ptr profile) const
 {
-    return profile
-        && !profile->isFallback() // Default/fallback profile is hardcoded
+    return profile && !profile->isFallback() // Default/fallback profile is hardcoded
         && QFileInfo(profile->path()).isWritable();
 }
 
 void ProfileSettings::setShortcutEditorVisible(bool visible)
 {
-    profilesList->setColumnHidden(ProfileModel::SHORTCUT, !visible);
+    profileListView->setColumnHidden(ProfileModel::SHORTCUT, !visible);
 }
